
from abc import ABC


class IExtensionAdapter(ABC):
    """
    The UML Diagrammer implements this interface in order to
    provide services to the extensions
    """
    def __init__(self):
        pass
